# -*- coding: utf8 -*-

import sys
import os
sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))

from cocos.director import director
from cocos.layer import Layer, ColorLayer
from cocos.scene import Scene
from cocos.scenes.transitions import *
from cocos.actions import *
from cocos.sprite import Sprite
from cocos.text import Label
import pyglet
from pyglet import gl, font

from pyglet.window import key

from video_player import VideoLayer

pyglet.resource.path.append("images")
pyglet.resource.path.append("videos")
pyglet.resource.reindex()

class ControlLayer(Layer):
    '''Handle keys.'''

    is_event_handler = True     #: enable pyglet's events

    def __init__(self, layers, start=0):
        super(ControlLayer, self).__init__()

        bg = ColorLayer(10,10,40,255)
        self._scenes = [Scene(bg, x, self) for x in layers]

        # primera y final
        black = Scene(ColorLayer(0,0,0,255), self)
        self._scenes.append(black)
        self._scene_idx = start

    @property
    def current_scene(self):
        return self._scenes[self._scene_idx]

    def on_key_press( self, k , m ):
#        print "===== key", k, m
        if k in (key.LEFT, key.UP, key.PAGEUP):
            if self._scene_idx > 0:
                self._scene_idx -= 1
                director.pop()
        elif k in (key.RIGHT, key.DOWN, key.PAGEDOWN):
            if self._scene_idx < len(self._scenes) - 1:
                self._scene_idx += 1
                director.push(self.current_scene)
#                import pdb;pdb.set_trace()
        elif k == key.ESCAPE:
            exit()


class TextLayer(Layer):

    def __init__(self, lines):
        super(TextLayer, self).__init__()

        self.labels = []
        for line in lines:
            if isinstance(line, tuple):
                size, text = line
            else:
                size = 48
                text = line
            l = Label(text, font_name="DejaVuSans", font_size=size,
                      anchor_x="center", anchor_y="center")
            l.alto = size + 4
            self.labels.append(l)

        ww, wh = director.get_window_size()
        total = sum(l.alto for l in self.labels)
        sep = (wh - total) // (len(self.labels) + 2)

        h = sep * 2
        for l in self.labels[::-1]:
            l.x = ww // 2
            l.y = h
            h += l.alto + sep

        l.element.color = (100,100,255,255)
        l.y = wh - 80

    def draw(self):
        for l in self.labels:
            l.draw()


class TextImagLayer(Layer):

    def __init__(self, lines, imags):
        super(TextImagLayer, self).__init__()

        self.labels = [Label(x, font_name="DejaVuSans", font_size=48,
                             anchor_x="center", anchor_y="center")
                       for x in lines]
        ww, wh = director.get_window_size()
        total = sum(52 for l in self.labels)
        sep = (wh - total) // (len(self.labels) + 2)

        h = sep * 2
        for l in self.labels[::-1]:
            l.x = ww // 2
            l.y = h
            h += 52 + sep

        l.element.color = (100,100,255,255)
        l.y = wh - 80


        for pos, img in imags:
            sp = Sprite(img)
            sp.position = pos
            self.add(sp)

    def draw(self):
        for l in self.labels:
            l.draw()


class ImagLayer(ColorLayer):

    def __init__(self, imags, bg=(0,0,0,255)):
        super(ImagLayer, self).__init__(*bg)

        for pos, img in imags:
            sp = Sprite(img)
            sp.position = pos
            self.add(sp)

class AutoVideoLayer(VideoLayer):
    '''video layer that plays automatically.'''

    def on_enter(self):
        self.player.play()

    def on_exit(self):
        self.player.pause()
        self.player.seek(0)

def main(start):
    director.init(width=1024, height=768, resizable=True)
#    import pdb;pdb.set_trace()
#    director.window.set_fullscreen(True)

    control = ControlLayer([
        ImagLayer([((512, 384), "caratula.png")]),
        TextLayer([u"Arrancamos", u"Python", u"charla", u"cerveza"]),
        TextImagLayer([u"Siempre supimos a dónde ir"],
                      [((512, 300), "donde.jpg")]),
        TextLayer([u"5 años", u"hicimos muchas cosas"]),
        TextLayer([u"Lista de Correo", u"~650 inscriptos",
                   u"principal recurso en castellano"]),
        TextLayer([u"Sitio Web", u"aprendiendo Python", u"FAQ", u"recetario",
                   u"bolsa de trabajo", u"etc, etc"]),
        TextLayer([u"Canal de IRC", u"consultas rápidas", u"social"]),
        TextLayer([u"36 reuniones", u"Capital: 26", u"Córdoba: 4",
                   u"Rosario: 3", u"Santa Fe: 3"]),
        TextLayer([u"5 Python Days", u"Córdoba: 2", u"Santa Fe: 2",
                   u"Mendoza: 1"]),
        TextLayer([u"2 PyCamps en Córdoba", u"cocos2d", u"lalita", u"cdpedia",
                   u"traducción de Trac"]),
        TextLayer([u"Participaciones", u"CaFeConf",
                   u"Jornadas Regionales de SL", u"Unlux",
                   u"Fábrica de fallas"]),
        TextImagLayer([u"Remeras"], [((270,340), "remera-v1.jpg"),
                                     ((770,340), "remera-v2.png")]),
        TextImagLayer([u"Propaganda"], [((332,480), "bandera.jpg"),
                                        ((820,320), "estandarte.jpg"),
                                        ((332,160), "minituto.jpg")]),
        AutoVideoLayer("videos/juegos.avi"),
        TextLayer([u"Grupo de usuarios", u"Personas", u"Comunidad"]),
        AutoVideoLayer("videos/personas.avi"),
        TextLayer([u"2004",
                   (24, u"Facundo Batista en"),
                   (18, u"http://listas.aditel.org/archivos/python-es/2004-April/004339.html"),
                   u'"...me encantaría armar', u"algún evento",
                   u"(no digo una conferencia,", u'no soy tan soñador)..."',
                  ]),
        TextLayer([u"2009",
                   (80, u"Primera"),
                   (80, u"PyCon"),
                   (80, u"Argentina")]),
        ImagLayer([((512, 384), "felices5.png")]),
    ], start)

    director.run(control.current_scene)

if __name__ == "__main__":
    if len(sys.argv) == 2:
        start = int(sys.argv[1])
    else:
        start = 0
    main(start)
